@@ -5,14 +5,11 @@
     utiml.cores = 1,
     utiml.seed = NA,
     utiml.use.probs = TRUE,
-    utiml.empty.prediction = FALSE
+    utiml.empty.prediction = FALSE,
+    utiml.random = sample(1:10) #Random value
   )
   toset <- !(names(op.utiml) %in% names(op))
   if (any(toset)) options(op.utiml[toset])
 
-  if (!exists('.Random.seed', envir = .GlobalEnv, inherits = FALSE)) {
-    sample(c()) #Force .Random.seed creation
-  }
-
   invisible()
 }
