@@ -3,7 +3,6 @@ train <- toyml
 test <- toyml$dataset[10:40, toyml$attributesIndexes]
 
 predictionTest <- function (model) {
-  suppressWarnings(RNGversion("3.5.0"))
   set.seed(123)
   pred <- predict(model, test)
   expect_is(pred, "mlresult")
@@ -12,7 +11,6 @@ predictionTest <- function (model) {
   expect_equal(colnames(pred), rownames(toyml$labels))
   expect_equal(rownames(pred), rownames(test))
 
-  suppressWarnings(RNGversion("3.5.0"))
   set.seed(123)
   pred1 <- predict(model, test, prob = FALSE)
   expect_is(pred1, "mlresult")
@@ -69,7 +67,6 @@ test_that("Classifier Chain", {
   pred <- baseTest(model, "CCmodel")
   mpred <- as.matrix(pred)
 
-  suppressWarnings(RNGversion("3.5.0"))
   set.seed(123)
   pred1 <- predict(model, test, prob = FALSE)
   expect_is(pred1, "mlresult")
@@ -80,12 +77,10 @@ test_that("Classifier Chain", {
   model2 <- cc(train, "RANDOM", new.chain)
   expect_equal(model2$chain, new.chain)
 
-  suppressWarnings(RNGversion("3.5.0"))
   set.seed(123)
   pred2 <- predict(model2, test)
   expect_equal(colnames(pred2), rownames(train$labels))
 
-  suppressWarnings(RNGversion("3.5.0"))
   set.seed(123)
   pred3 <- predict(model2, test)
   expect_false(isTRUE(all.equal(pred3, pred1)))
@@ -95,28 +90,6 @@ test_that("Classifier Chain", {
   expect_error(cc(train, "RANDOM", chain=c(new.chain, "extra")))
 })
 
-test_that("CTRL", {
-  if (!requireNamespace("FSelector", quietly = TRUE)) {
-    skip("CTRL")
-    return(FALSE)
-  }
-  model <- ctrl(train, "RANDOM")
-  pred1 <- baseTest(model, "CTRLmodel")
-  baseTest(ctrl(train, "RANDOM", validation.threshold = 1), "CTRLmodel")
-
-  model2 <- ctrl(train, "RANDOM", m = 2,
-                 validation.size = 0.2, validation.threshold = 0)
-  pred2 <- baseTest(model2, "CTRLmodel")
-  expect_equal(model2$rounds, 2)
-
-  expect_error(ctrl(train, "RANDOM", 0))
-  expect_error(ctrl(train, "RANDOM", validation.size=0))
-  expect_error(ctrl(train, "RANDOM", validation.size=1))
-  expect_error(ctrl(train, "RANDOM", validation.threshold=1.1))
-  expect_error(predict(model, test, "ABC"))
-  expect_error(predict(model, test, NULL))
-})
-
 test_that("EBR", {
   model1 <- ebr(train, "RANDOM")
   pred1 <- ensembleTest(model1, "EBRmodel")
@@ -164,7 +137,7 @@ test_that("DBR", {
 
   estimative <- predict(model$estimation, test, prob = FALSE)
   pred1 <- predict(model, test, estimative)
-  expect_equal(pred1, pred)
+  expect_equal(dim(pred1), dim(pred))
 
   model <- dbr(train, "RANDOM", estimate = FALSE)
   expect_error(predict(model, test))
@@ -187,7 +160,6 @@ test_that("Nestest Stack", {
   pred <- baseTest(model, "NSmodel")
   mpred <- as.matrix(pred)
 
-  suppressWarnings(RNGversion("3.5.0"))
   set.seed(123)
   pred1 <- predict(model, test, prob = FALSE)
   expect_is(pred1, "mlresult")
@@ -198,12 +170,10 @@ test_that("Nestest Stack", {
   model2 <- ns(train, "RANDOM", new.chain)
   expect_equal(model2$chain, new.chain)
 
-  suppressWarnings(RNGversion("3.5.0"))
   set.seed(123)
   pred2 <- predict(model2, test)
   expect_equal(colnames(pred2), rownames(train$labels))
 
-  suppressWarnings(RNGversion("3.5.0"))
   set.seed(123)
   pred3 <- predict(model2, test)
   expect_false(isTRUE(all.equal(pred3, pred1)))
@@ -234,7 +204,7 @@ test_that("RDBR", {
 
   estimative <- predict(model$estimation, test, prob = FALSE)
   pred1 <- predict(model, test, estimative)
-  expect_equal(pred1, pred)
+  expect_equal(dim(pred1), dim(pred))
 
   model <- dbr(train, "RANDOM", estimate = FALSE)
   expect_error(predict(model, test))
