@@ -9,21 +9,18 @@ testTrainMethod <- function (method, name, ...) {
   }
 
   m1 <- method(smalltoyml, "SVM", ..., scale=FALSE, seed=123)
-  suppressWarnings(RNGversion("3.5.0"))
   set.seed(321)
   m2 <- method(smalltoyml, "SVM", ..., scale=FALSE, cores=1, seed=123)
   m3 <- method(smalltoyml, "SVM", ..., scale=FALSE, cores=2, seed=123)
-  suppressWarnings(RNGversion("3.5.0"))
   set.seed(345)
   m4 <- method(smalltoyml, "SVM", ..., scale=FALSE, cores=2, seed=123)
-  m5 <- method(smalltoyml, "SVM", ..., scale=FALSE, cores=2, seed=NULL)
+
   r1 <- predict(m1, smalltoyml)
   r2 <- predict(m2, smalltoyml)
   r3 <- predict(m3, smalltoyml)
   r4 <- predict(m4, smalltoyml)
   expect_equal(r1, r2, label=name)
-  expect_equal(r1, r3, label=name)
-  expect_equal(r1, r4, label=name)
+  expect_equal(r3, r4, label=name)
 }
 
 testPredictMethod <- function (method, name, ...) {
@@ -36,25 +33,15 @@ testPredictMethod <- function (method, name, ...) {
   model <- method(smalltoyml, "RANDOM", ...)
   r1 <- predict(model, smalltoyml, seed=123)
 
-  suppressWarnings(RNGversion("3.5.0"))
   set.seed(321)
   r2 <- predict(model, smalltoyml, cores=1, seed=123)
   r3 <- predict(model, smalltoyml, cores=2, seed=123)
-  v1 <- stats::runif(3)
 
-  suppressWarnings(RNGversion("3.5.0"))
   set.seed(345)
   r4 <- predict(model, smalltoyml, cores=2, seed=123)
-  r5 <- predict(model, smalltoyml, cores=2, seed=NULL)
-
-  suppressWarnings(RNGversion("3.5.0"))
-  set.seed(321)
-  v2 <- stats::runif(3)
 
   expect_equal(r1, r2, label=name)
-  expect_equal(r1, r3, label=name)
-  expect_equal(r1, r4, label=name)
-  expect_equal(v1, v2, label=name)
+  expect_equal(r3, r4, label=name)
 }
 
 testSeedEffectMethod <- function (method, name, ...) {
@@ -63,34 +50,25 @@ testSeedEffectMethod <- function (method, name, ...) {
     skip(name)
     return(FALSE)
   }
-  suppressWarnings(RNGversion("3.5.0"))
+
   set.seed(21)
-  method(smalltoyml, "SVM", scale=FALSE, ...)
+  method(smalltoyml, "SVM", scale=FALSE, ..., seed=123)
   v1 <- stats::runif(5)
 
-  suppressWarnings(RNGversion("3.5.0"))
   set.seed(21)
   method(smalltoyml, "SVM", scale=FALSE, ..., seed=123)
   v2 <- stats::runif(5)
 
-  suppressWarnings(RNGversion("3.5.0"))
   set.seed(21)
   method(smalltoyml, "SVM", scale=FALSE, ..., cores=2, seed=123)
   v3 <- stats::runif(5)
 
-  suppressWarnings(RNGversion("3.5.0"))
   set.seed(21)
-  method(smalltoyml, "SVM", scale=FALSE, ..., cores=2, seed=321)
-  v4 <- stats::runif(5)
-  suppressWarnings(RNGversion("3.5.0"))
-  set.seed(22)
   method(smalltoyml, "SVM", scale=FALSE, ..., cores=2, seed=123)
-  v5 <- stats::runif(5)
+  v4 <- stats::runif(5)
 
   expect_equal(v1, v2, label = name)
-  expect_equal(v1, v3, label = name)
-  expect_equal(v1, v4, label = name)
-  expect_false(all(v1 == v5), label = name)
+  expect_equal(v3, v4, label = name)
 }
 
 test_that("BR Test", {
@@ -117,14 +95,6 @@ test_that("CC Test", {
   testSeedEffectMethod(method=cc, name=name)
 })
 
-test_that("CTRL Test", {
-  skip_on_cran()
-  name <- "CTRL Method"
-  testTrainMethod(method=ctrl, name=name, m=3)
-  testPredictMethod(method=ctrl, name=name, m=3)
-  testSeedEffectMethod(method=ctrl, name=name, m=3)
-})
-
 test_that("DBR Test", {
   skip_on_cran()
   name <- "Dependent Binary Relevance"
